@@ -16,9 +16,19 @@
 #' Default is `c("row", "column")`. Use `margin  = NULL` to suppress both
 #' row and column margins.
 #' @param margin_text Text to display for margin totals. Default is `"Total"`
+#' @param digits Specifies the number of decimal
+#' places to round the summary statistics. By default integers are shown
+#' to the zero decimal places, and percentages are formatted with `style_percent()`.
+#' If you would like to modify either of these, pass a vector of integers
+#' indicating the number of decimal places to round the statistics.
+#' For example, if the
+#' statistic being calculated is `"{n} ({p}%)"` and you want the percent rounded
+#' to 2 decimal places use `digits = c(0, 2)`. User
+#' may also pass a styling function: `digits = style_sigfig`
 #' @inheritParams tbl_summary
 #'
 #' @family tbl_cross tools
+#' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
 #' @author Karissa Whiting, Daniel D. Sjoberg
 #' @export
 #' @return A `tbl_cross` object
@@ -47,6 +57,7 @@ tbl_cross <- function(data,
                       col = NULL,
                       label = NULL,
                       statistic = NULL,
+                      digits = NULL,
                       percent = c("none", "column", "row", "cell"),
                       margin = c("column", "row"),
                       missing = c("ifany", "always", "no"),
@@ -117,7 +128,14 @@ tbl_cross <- function(data,
   }
 
   # get labels -----------------------------------------------------------------
-  label <- .formula_list_to_named_list(x = label, data = data)
+  label <-
+    .formula_list_to_named_list(
+      x = label,
+      data = data,
+      arg_name = "label",
+      type_check = chuck(type_check, "is_string", "fn"),
+      type_check_msg = chuck(type_check, "is_string", "msg")
+    )
   new_label <- list()
 
   new_label[[row]] <- label[[row]] %||% attr(data[[row]], "label") %||% row
@@ -152,11 +170,13 @@ tbl_cross <- function(data,
   }
 
   # create main table ----------------------------------------------------------
-  x <- data %>%
+  x <-
+    data %>%
     select(any_of(c(row, col, "..total.."))) %>%
     tbl_summary(
       by = col,
       statistic = stats::as.formula(glue("everything() ~ '{statistic}'")),
+      digits = switch(!is.null(digits), everything() ~ digits),
       percent = ifelse(percent == "none", "cell", percent),
       label = new_label,
       missing_text = missing_text,
