@@ -4,7 +4,7 @@
 #' that is publication-ready. The function is highly customizable
 #' allowing the user to obtain a bespoke summary table of the
 #' regression model results. Review the
-#' \href{http://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html}{tbl_regression vignette}
+#' \href{https://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html}{tbl_regression vignette}
 #' for detailed examples.
 #'
 #' @section Methods:
@@ -56,11 +56,12 @@
 #' then tidying of the model is attempted with `parameters::model_parameters()`,
 #' if installed.
 #' @param add_estimate_to_reference_rows add a reference value. Default is FALSE
+#' @param conf.int Logical indicating whether or not to include a confidence
+#' interval in the output. Defaults to `TRUE`.
 #' @param ... Not used
-#' @param exclude DEPRECATED
-#' @param show_yesno DEPRECATED
 #' @author Daniel D. Sjoberg
-#' @seealso See tbl_regression \href{http://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html}{vignette} for detailed examples
+#' @seealso See tbl_regression \href{https://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html}{vignette} for detailed examples
+#' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
 #' @family tbl_regression tools
 #' @export
 #' @rdname tbl_regression
@@ -107,27 +108,9 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
                                    estimate_fun = NULL, pvalue_fun = NULL,
                                    tidy_fun = NULL,
                                    add_estimate_to_reference_rows = FALSE,
-                                   show_yesno = NULL, exclude = NULL, ...) {
+                                   conf.int = NULL, ...) {
   # deprecated arguments -------------------------------------------------------
-  if (!is.null(show_yesno)) {
-    lifecycle::deprecate_stop(
-      "1.2.2", "tbl_regression(show_yesno = )",
-      "tbl_regression(show_single_row = )"
-    )
-  }
-
-  if (!rlang::quo_is_null(rlang::enquo(exclude))) {
-    lifecycle::deprecate_stop(
-      "1.2.5",
-      "gtsummary::tbl_regression(exclude = )",
-      "tbl_regression(include = )",
-      details = paste0(
-        "The `include` argument accepts quoted and unquoted expressions similar\n",
-        "to `dplyr::select()`. To exclude variable, use the minus sign.\n",
-        "For example, `include = -c(age, stage)`"
-      )
-    )
-  }
+  .tbl_regression_deprecated_arguments(...)
 
   # setting defaults -----------------------------------------------------------
   tidy_fun <- tidy_fun %||% broom.helpers::tidy_with_broom_or_parameters
@@ -149,6 +132,9 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
     conf.level %||%
     get_theme_element("tbl_regression-arg:conf.level") %||%
     getOption("gtsummary.conf.level", default = 0.95)
+  conf.int <-
+    conf.int %||%
+    get_theme_element("tbl_regression-arg:conf.int", default = TRUE)
   add_estimate_to_reference_rows <-
     add_estimate_to_reference_rows %||%
     get_theme_element("tbl_regression-arg:add_estimate_to_reference_rows", default = FALSE)
@@ -174,7 +160,8 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
       conf.level = conf.level, intercept = intercept,
       label = label, show_single_row = !!show_single_row,
       include = !!include,
-      add_estimate_to_reference_rows = add_estimate_to_reference_rows
+      add_estimate_to_reference_rows = add_estimate_to_reference_rows,
+      conf.int = conf.int
     )
 
   # saving evaluated `label`, `show_single_row`, and `include` -----------------
@@ -182,7 +169,9 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
     .formula_list_to_named_list(
       x = label,
       var_info = table_body,
-      arg_name = "label"
+      arg_name = "label",
+      type_check = chuck(type_check, "is_string", "fn"),
+      type_check_msg = chuck(type_check, "is_string", "msg")
     )
 
   func_inputs$show_single_row <-
@@ -216,8 +205,8 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
 
   # table of column headers
   x <-
-    .create_gtsummary_object(
-      table_body = table_body,
+    .create_gtsummary_object(table_body = table_body) %>%
+    purrr::list_modify(
       N = pluck(table_body, "N_obs", 1),
       n = pluck(table_body, "N_obs", 1), # i want to remove this eventually
       N_event = pluck(table_body, "N_event", 1), model_obj = x,
@@ -256,3 +245,26 @@ tbl_regression.default <- function(x, label = NULL, exponentiate = FALSE,
   # return results -------------------------------------------------------------
   x
 }
+
+.tbl_regression_deprecated_arguments <- function(show_yesno = NULL, exclude = NULL) {
+  if (!is.null(show_yesno)) {
+    lifecycle::deprecate_stop(
+      "1.2.2", "tbl_regression(show_yesno = )",
+      "tbl_regression(show_single_row = )"
+    )
+  }
+
+  if (!rlang::quo_is_null(rlang::enquo(exclude))) {
+    lifecycle::deprecate_stop(
+      "1.2.5",
+      "gtsummary::tbl_regression(exclude = )",
+      "tbl_regression(include = )",
+      details = paste0(
+        "The `include` argument accepts quoted and unquoted expressions similar\n",
+        "to `dplyr::select()`. To exclude variable, use the minus sign.\n",
+        "For example, `include = -c(age, stage)`"
+      )
+    )
+  }
+  invisible()
+}
