@@ -598,7 +598,7 @@ tbl_summary_input_checks <- function(data, by, label, type, value, statistic,
   # label ----------------------------------------------------------------------
   if (!is.null(label) & is.null(names(label))) { # checking names for deprecated named list input
 
-    # all sepcifed labels must be a string of length 1
+    # all specified labels must be a string of length 1
     if (inherits(label, "formula")) label <- list(label)
     if (!every(label, ~ rlang::is_string(eval_rhs(.x)))) {
       stop(glue(
@@ -763,6 +763,7 @@ stat_label_match <- function(stat_display, iqr = TRUE, range = TRUE) {
       "{mean}", "Mean",
       "{sd}", "SD",
       "{var}", "Variance",
+      "{sum}", "Sum",
       "{n}", "n",
       "{N}", "N",
       "{p}%", "%",
@@ -1111,7 +1112,8 @@ extracting_function_calls_from_stat_display <- function(stat_display, variable)
 adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
                                       stat_display, digits) {
   # setting the default formatting ---------------------------------------------
-  percent_fun <- get_theme_element("tbl_summary-fn:percent_fun") %||%
+  percent_fun <-
+    get_theme_element("tbl_summary-fn:percent_fun") %||%
     getOption("gtsummary.tbl_summary.percent_fun", default = style_percent)
 
   # extracting statistics requested
@@ -1210,9 +1212,13 @@ adding_formatting_as_attr <- function(df_stats, data, variable, summary_type,
           attr(column, "fmt_fun") <- style_number
         }
 
-        # that should cove everything, but adding this just in case
+        # that should cover everything in `tbl_summary()`,
+        # but these are somtimes used in `tbl_custom_summary()`
+        else if (is.numeric(column)) {
+          attr(column, "fmt_fun") <- style_sigfig
+        }
         else {
-          attr(column, "fmt_fun") <- style_number
+          attr(column, "fmt_fun") <- as.character
         }
 
         # return column
