@@ -25,7 +25,7 @@ if (!identical(Sys.getenv("IN_PKGDOWN"), "true") &&
     !tolower(as.list(Sys.info())$user) %in% c("sjobergd", "currym", "whitingk", "whiting")) {
   msg <- 
     paste("View this vignette on the",
-          "[package website](http://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html).")
+          "[package website](https://www.danieldsjoberg.com/gtsummary/articles/tbl_regression.html).")
   cat(msg)
   knitr::knit_exit()
 }
