@@ -1,5 +1,4 @@
-context("test-assign_dichotomous_value")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_df <-
   tibble::tibble(
@@ -13,7 +12,6 @@ test_that("assign_dichotomous_value_one for yes/no factors", {
     assign_dichotomous_value_one(
       data = test_df, variable = "v2",
       summary_type = "dichotomous",
-      class = "factor",
       value = NULL
     ),
     "yes"
@@ -25,8 +23,7 @@ test_that("input checks", {
     assign_dichotomous_value(
       data = trial, variable = "stage",
       summary_type = "dichotomous",
-      class = "factor", value = NULL
-    ),
-    "'stage' is dichotomous, but I was unable to determine the level.*"
+      value = NULL
+    )
   )
 })
