@@ -1,5 +1,4 @@
-context("test-sort_p")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("no errors/warnings with standard use after tbl_summary() and add_p()", {
   table1 <- trial %>%
@@ -12,6 +11,7 @@ test_that("no errors/warnings with standard use after tbl_summary() and add_p()"
 
 
 test_that("no errors/warnings with standard use after tbl_regression() and add_global_p()", {
+  skip_if_not(requireNamespace("car"))
   regress1 <- glm(response ~ age + grade, trial, family = binomial(link = "logit")) %>%
     tbl_regression(exponentiate = TRUE) %>%
     add_global_p()
@@ -21,6 +21,7 @@ test_that("no errors/warnings with standard use after tbl_regression() and add_g
 })
 
 test_that("no errors/warnings with standard use after tbl_regression() and add_global_p()", {
+  skip_if_not(requireNamespace("car"))
   regress2 <-
     tbl_uvregression(
       trial %>% dplyr::select(response, age, grade),
