@@ -1,3 +1,6 @@
+skip_on_cran()
+
+
 test_that("tbl_custom_summary() basics", {
   mean_age <- function(data, ...) {
     dplyr::tibble(mean_age = mean(data$age, na.rm = TRUE))
@@ -9,9 +12,9 @@ test_that("tbl_custom_summary() basics", {
       tbl_custom_summary(
         include = c("grade", "response", "marker"),
         by = "trt",
-        stat_fns = everything() ~ mean_age,
-        statistic = everything() ~ "{mean_age}",
-        digits = everything() ~ 1
+        stat_fns = ~ mean_age,
+        statistic = ~ "{mean_age}",
+        digits = ~ 1
       ) %>%
       add_overall(last = TRUE) %>%
       modify_footnote(all_stat_cols() ~ "Mean age") %>%
@@ -56,9 +59,6 @@ test_that("tbl_custom_summary() basics", {
     c(NA, "46.2", "47.5", "48.1", "49.8", "7", "47.0", "10")
   )
 
-  # table with character stat, full_data and using some tbl_summary tools
-  skip_on_cran()
-
   diff_to_great_mean <- function(data, full_data, ...) {
     mean <- mean(data$marker, na.rm = TRUE)
     great_mean <- mean(full_data$marker, na.rm = TRUE)
@@ -72,7 +72,8 @@ test_that("tbl_custom_summary() basics", {
   }
 
   expect_error(
-    tbl <- trial %>%
+    tbl <-
+      trial %>%
       tbl_custom_summary(
         include = c("grade", "stage"),
         by = "trt",
@@ -132,6 +133,16 @@ test_that("tbl_custom_summary() basics", {
     tbl$stat_1,
     c("1.02 [0.83; 1.20]", "6", "20.2 [19.2; 21.2]")
   )
+
+  expect_error(
+    trial %>%
+      tbl_custom_summary(
+        include = c("marker", "ttdeath"),
+        by = "trt",
+        stat_fns = mean_ci, # incorrect, right syntax is '~ mean_ci'
+        statistic = everything() ~ "{mean} [{conf.low}; {conf.high}]"
+      )
+  )
 })
 
 test_that("tbl_custom_summary() manage factor levels with no observation", {
@@ -217,3 +228,31 @@ test_that("tbl_custom_summary() helpers work as expected", {
       "22.3% (192/862) [20-25]")
   )
 })
+
+
+test_that("character summaries do not cause error", {
+  diff_to_great_mean <- function(data, full_data, ...) {
+    mean <- mean(data$marker, na.rm = TRUE)
+    great_mean <- mean(full_data$marker, na.rm = TRUE)
+    diff <- mean - great_mean
+    dplyr::tibble(
+      mean = mean,
+      great_mean = great_mean,
+      diff = diff,
+      level = ifelse(diff > 0, "high", "low"),
+      date = Sys.Date()
+    )
+  }
+
+  expect_error(
+    trial %>%
+      tbl_custom_summary(
+        include = c("stage"),
+        by = "trt",
+        stat_fns = ~ diff_to_great_mean,
+        statistic = ~ "{mean} ({level}) [{date}]"
+      ),
+    NA
+  )
+
+})
