@@ -20,6 +20,12 @@ test_that("lm: no errors/warnings with standard use", {
       method = lm,
       y = mpg
     ), NA)
+
+  expect_false(
+    "ci" %in%
+      names(tbl_uvregression(mtcars, method = lm, y = mpg, conf.int = FALSE) %>%
+          as_tibble(col_labels = FALSE))
+  )
 })
 
 test_that("geeglm: no errors/warnings with standard use", {
